#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retry
version:              0.8.1.2
visibility:           public
id:                   retry-0.8.1.2-CZdjYjDlI2c1IJ5AtphJdU
key:                  retry-0.8.1.2-CZdjYjDlI2c1IJ5AtphJdU
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  a55f78391b1992c31f3ddb04c98dccd3
exposed:              True
exposed-modules:      Control.Retry
import-dirs:          /usr/lib/ghc-8.10.5/site-local/retry-0.8.1.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/retry-0.8.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/retry-0.8.1.2
hs-libraries:         HSretry-0.8.1.2-CZdjYjDlI2c1IJ5AtphJdU
depends:
    base-4.14.2.0 exceptions-0.10.4 ghc-prim-0.6.1
    random-1.2.0-GZbCBA9NAlUBaVRSIi1HYu transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

